Citing
======

.. .. toctree::
..    :titlesonly:
..    :maxdepth: 4

To cite **gfn**, please use the following reference:

.. code-block:: bibtex

   @article{Morrison2024,
      title = {{GFN}: {A} graph feedforward network for resolution-invariant reduced operator learning in multifidelity applications},
      author = {Morrison, Oisín M. and Pichi, Federico and Hesthaven, Jan S.},
      journal = {Computer Methods in Applied Mechanics and Engineering},
      volume = {432},
      pages = {117458},
      year = {2024},
      doi = {10.1016/j.cma.2024.117458},
   }
